@@ -129,9 +129,7 @@ NCP_RNA<-function(seqs,binaryType="strBin",outFormat="mat",outputFileDist="",lab
     else{
       stop("ERROR! Choose one of 'strBin', 'logicBin', or 'numBin' for binaryFormat")
     }
-    ad<-system.file("extdata",package="ftrCOOL")
-    ad<-paste0(ad,"/ncp.csv")
-    write.csv(featureMatrix,file = ad)
+
     return(featureMatrix)
 
   } else if(outFormat=="txt"){
@@ -149,9 +147,6 @@ NCP_RNA<-function(seqs,binaryType="strBin",outFormat="mat",outputFileDist="",lab
       cods<-c(namecods,cods)
       temp<-paste(cods,collapse = "\t")
       write(temp,outputFileDist,append = TRUE)
-
-      #write(temp,"~/Desktop/list.txt",append = TRUE)
-      #return(cods)
     })
   }
   else {
